==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/hole/dialogs_nl.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("Het is een spookveld.")

dialogId("v-bojim", "font_big",
        "I fear it will be dificult to move things over this hole.")
dialogStr("Ik ben bang dat het moeilijk wordt om dingen over dit gat heen te duwen")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Alsjeblieft.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Is daar iemand?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Wie is daar?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Ik denk dat de hoorn het niet doet.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")
dialogStr("Leg dat onmiddelijk terug. Die indiaanse hoofdtooi is van mij.")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Leg dat onmiddelijk terug! Dat is van mij!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")
dialogStr("Oehoehoehoe, ik ben een indiaan! Leg dat onmiddelijk terug!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("Oehoehoehoe. Leg dat onmiddelijk terug!")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Waar duw je mij heen? Ik ben de beroemde Winnetoe!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")
dialogStr("Sorry hoor, maar we hebben het echt nodig.")

dialogId("v-nedame0", "font_big",
        "How can it be yours, if you are not indian?")
dialogStr("Hoe kan het van jou zijn als je geen indiaan bent?")

dialogId("m-nedame1", "font_small",
         "You can't be indian because you are not red?")
dialogStr("Je kunt geen indiaan zijn omdat je niet rood bent?")

dialogId("v-nedame1", "font_big", "I can't demur anything.")
dialogStr("Ik ontken niks.")

dialogId("v-neber", "font_big",
"Player, if you are an indian, don't perceive as an discrimination please.")
dialogStr("Speler, als je een oorspronkelijke bewoner van Amerika bent, vat dit dan alsjeblieft niet discriminerend op.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("Misschien is het een magische hoorn.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Probeer eens.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")
dialogStr("Hallo, ik wil het staal bij de uitgang weg.")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
dialogStr("Doe het terug. Het moet door de speler worden opgelost, niet door ons.")

==> fillets-ng-data_0.9.0.orig.tar.gz: fillets-ng-data-0.9.0/script/hole/dialogs_nl.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("Het is een spookveld.")

dialogId("v-bojim", "font_big",
        "I fear it will be dificult to move things over this hole.")
dialogStr("Ik ben bang dat het moeilijk wordt om dingen over dit gat heen te duwen")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Alsjeblieft.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Is daar iemand?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Wie is daar?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Ik denk dat de hoorn het niet doet.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")
dialogStr("Leg dat onmiddelijk terug. Die indiaanse hoofdtooi is van mij.")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Leg dat onmiddelijk terug! Dat is van mij!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")
dialogStr("Oehoehoehoe, ik ben een indiaan! Leg dat onmiddelijk terug!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("Oehoehoehoe. Leg dat onmiddelijk terug!")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Waar duw je mij heen? Ik ben de beroemde Winnetoe!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")
dialogStr("Sorry hoor, maar we hebben het echt nodig.")

dialogId("v-nedame0", "font_big",
        "How can it be yours, if you are not indian?")
dialogStr("Hoe kan het van jou zijn als je geen indiaan bent?")

dialogId("m-nedame1", "font_small", "You can’t be indian because you are not red?")
dialogStr("Je kunt geen indiaan zijn omdat je niet rood bent?")

dialogId("v-nedame1", "font_big", "I can’t demur anything.")
dialogStr("Ik ontken niks.")

dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive as an discrimination please.")
dialogStr("Speler, als je een oorspronkelijke bewoner van Amerika bent, vat dit dan alsjeblieft niet discriminerend op.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("Misschien is het een magische hoorn.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Probeer eens.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")
dialogStr("Hallo, ik wil het staal bij de uitgang weg.")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
dialogStr("Doe het terug. Het moet door de speler worden opgelost, niet door ons.")
